@@ -124,12 +124,12 @@ class NetWrapper(nn.Module):
         return projector.to(hidden)
 
     def get_representation(self, x):
-        if not self.hook_registered:
-            self._register_hook()
-
         if self.layer == -1:
             return self.net(x)
 
+        if not self.hook_registered:
+            self._register_hook()
+
         _ = self.net(x)
         hidden = self.hidden
         self.hidden = None
@@ -156,7 +156,7 @@ class BYOL(nn.Module):
             augs.RandomHorizontalFlip(),
             RandomApply(filters.GaussianBlur2d((3, 3), (1.5, 1.5)), p=0.1),
             augs.RandomResizedCrop((image_size, image_size)),
-            color.Normalize(mean=torch.tensor([0.485, 0.456, 0.406]), std=torch.tensor([0.229, 0.224, 0.225]))
+            augs.Normalize(mean=torch.tensor([0.485, 0.456, 0.406]), std=torch.tensor([0.229, 0.224, 0.225]))
         )
 
         self.augment = default(augment_fn, DEFAULT_AUG)
